==> openvdb-12.0.1-2-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/dir_c9229911bfd1cba3327f6b216c5f36b0.js <==
var dir_c9229911bfd1cba3327f6b216c5f36b0 =
[
    [ "impl", "dir_f1837fd804c771cd6a6400b5e11ed687.html", "dir_f1837fd804c771cd6a6400b5e11ed687" ],
    [ "AttributeArray.h", "AttributeArray_8h.html", "AttributeArray_8h" ],
    [ "AttributeArrayString.h", "AttributeArrayString_8h.html", "AttributeArrayString_8h" ],
    [ "AttributeGroup.h", "AttributeGroup_8h.html", "AttributeGroup_8h" ],
    [ "AttributeSet.h", "AttributeSet_8h.html", "AttributeSet_8h" ],
    [ "IndexFilter.h", "IndexFilter_8h.html", "IndexFilter_8h" ],
    [ "IndexIterator.h", "IndexIterator_8h.html", "IndexIterator_8h" ],
    [ "PointAdvect.h", "points_2PointAdvect_8h.html", "points_2PointAdvect_8h" ],
    [ "PointAttribute.h", "PointAttribute_8h.html", "PointAttribute_8h" ],
    [ "PointConversion.h", "PointConversion_8h.html", "PointConversion_8h" ],
    [ "PointCount.h", "PointCount_8h.html", "PointCount_8h" ],
    [ "PointDataGrid.h", "PointDataGrid_8h.html", "PointDataGrid_8h" ],
    [ "PointDelete.h", "PointDelete_8h.html", "PointDelete_8h" ],
    [ "PointGroup.h", "PointGroup_8h.html", "PointGroup_8h" ],
    [ "PointMask.h", "PointMask_8h.html", "PointMask_8h" ],
    [ "PointMove.h", "PointMove_8h.html", "PointMove_8h" ],
    [ "PointRasterizeFrustum.h", "PointRasterizeFrustum_8h.html", "PointRasterizeFrustum_8h" ],
    [ "PointRasterizeSDF.h", "PointRasterizeSDF_8h.html", "PointRasterizeSDF_8h" ],
    [ "PointRasterizeTrilinear.h", "PointRasterizeTrilinear_8h.html", "PointRasterizeTrilinear_8h" ],
    [ "PointReplicate.h", "PointReplicate_8h.html", "PointReplicate_8h" ],
    [ "PointSample.h", "PointSample_8h.html", "PointSample_8h" ],
    [ "PointScatter.h", "points_2PointScatter_8h.html", "points_2PointScatter_8h" ],
    [ "PointStatistics.h", "PointStatistics_8h.html", "PointStatistics_8h" ],
    [ "PointTransfer.h", "PointTransfer_8h.html", "PointTransfer_8h" ],
    [ "StreamCompression.h", "StreamCompression_8h.html", "StreamCompression_8h" ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/dir_c9229911bfd1cba3327f6b216c5f36b0.js <==
var dir_c9229911bfd1cba3327f6b216c5f36b0 =
[
    [ "impl", "dir_f1837fd804c771cd6a6400b5e11ed687.html", "dir_f1837fd804c771cd6a6400b5e11ed687" ],
    [ "AttributeArray.h", "AttributeArray_8h.html", "AttributeArray_8h" ],
    [ "AttributeArrayString.h", "AttributeArrayString_8h.html", "AttributeArrayString_8h" ],
    [ "AttributeGroup.h", "AttributeGroup_8h.html", "AttributeGroup_8h" ],
    [ "AttributeSet.h", "AttributeSet_8h.html", "AttributeSet_8h" ],
    [ "IndexFilter.h", "IndexFilter_8h.html", "IndexFilter_8h" ],
    [ "IndexIterator.h", "IndexIterator_8h.html", "IndexIterator_8h" ],
    [ "PointAdvect.h", "points_2PointAdvect_8h.html", "points_2PointAdvect_8h" ],
    [ "PointAttribute.h", "PointAttribute_8h.html", "PointAttribute_8h" ],
    [ "PointConversion.h", "PointConversion_8h.html", "PointConversion_8h" ],
    [ "PointCount.h", "PointCount_8h.html", "PointCount_8h" ],
    [ "PointDataGrid.h", "PointDataGrid_8h.html", "PointDataGrid_8h" ],
    [ "PointDelete.h", "PointDelete_8h.html", "PointDelete_8h" ],
    [ "PointGroup.h", "PointGroup_8h.html", "PointGroup_8h" ],
    [ "PointMask.h", "PointMask_8h.html", "PointMask_8h" ],
    [ "PointMove.h", "PointMove_8h.html", "PointMove_8h" ],
    [ "PointRasterizeFrustum.h", "PointRasterizeFrustum_8h.html", "PointRasterizeFrustum_8h" ],
    [ "PointRasterizeSDF.h", "PointRasterizeSDF_8h.html", "PointRasterizeSDF_8h" ],
    [ "PointRasterizeTrilinear.h", "PointRasterizeTrilinear_8h.html", "PointRasterizeTrilinear_8h" ],
    [ "PointReplicate.h", "PointReplicate_8h.html", "PointReplicate_8h" ],
    [ "PointSample.h", "PointSample_8h.html", "PointSample_8h" ],
    [ "PointScatter.h", "points_2PointScatter_8h.html", "points_2PointScatter_8h" ],
    [ "PointStatistics.h", "PointStatistics_8h.html", "PointStatistics_8h" ],
    [ "PointTransfer.h", "PointTransfer_8h.html", "PointTransfer_8h" ],
    [ "PrincipalComponentAnalysis.h", "PrincipalComponentAnalysis_8h.html", "PrincipalComponentAnalysis_8h" ],
    [ "StreamCompression.h", "StreamCompression_8h.html", "StreamCompression_8h" ]
];
